local _core = require("core")
local _logger = require("logging")
local _storage = require("storage")

local credentials = _storage.get_table(_G.constants.STORAGE_ACCOUNT_KEY)

if not credentials then
    _logger.warning("No account is configured... The user did not log in yet.")
end

local function CreateDevice ()
    local my_gateway_id = (_core.get_gateway() or {}).id
    if not my_gateway_id then
        return nil
    end

    local count = 0
    for _, device in pairs(_core.get_devices() or {}) do
        if device.gateway_id == my_gateway_id then
            count = count + 1
            if not credentials or count >=2 then
                return device.id
            end
        end
    end

    _logger.info("Create new fake device")
    return _core.add_device {
        type = "switch.inwall",
        device_type_id = "switch.inwall.fake",
        category = "switch",
        subcategory = "interior_plugin",
        battery_powered = false,
        gateway_id = _core.get_gateway().id,
        name = not credentials and "Fake Switch (install)" or "Fake Switch (login)",
        info = {
            manufacturer = "Ezlo",
            model = "1.0"
        }
    }
end

local function CreateItem (device_id)
    if not device_id then
        _logger.error("Cannot create item. Missing device_id...")
        return
    end
    for _, item in ipairs(_core.get_items_by_device_id(device_id) or {}) do
        return
    end
	
    _logger.info("Create new fake 'switch' item")
    _core.add_item({
        device_id = device_id,
        name = "switch",
        value_type = "bool",
        value = false,
        has_getter = true,
        has_setter = true
    })
end

local device_id = CreateDevice()

CreateItem(device_id)
