-- The 'core' module provides the ability to work with the Ezlo Lua API to manage devices, items, settings and more.
-- Lua core module documentation is available at: https://developer.mios.com/api/scripting/modules/core/functionality/

local _core = require("core")

-- Any parameter passed to the script can be obtained by using the vararg expression "..."
-- See https://www.lua.org/manual/5.4/manual.html#3.4.11
-- We store the parameter in the "args" variable for later use (while also making sure to initialize it if no parameters are passed):

local args = ... or {}

-- This is a demo plugin, so we directly update our existing item with the new value and we're done:

_core.update_item_value(args.item_id, args.value)

-- In a real-world case we would write logic in this script for the following situations:

-- 1. Item initialization
--    * Create an item if it has not already been created
--    * Initialize the item

-- 2. Item update
--    * This usually means sending a request to a real device then waiting for the response
--    * Based on the response we update the item value
--      * OR we set the device as offline 
--      * OR mark an error by changing device status
--      * OR broadcast a custom error

-- 3. Item sync/remove
--    * In certain situations you may want to dynamically add/remove items
--    * For example - you have a device setting which controls the max. number of items on a device (e.g. the number 
--    of buttons on a remote control). This call can remove some of them or add them back later based on your logic.

-- 4. Basically, in item (and device settings - not covered in this demo), scripts is where all the 'plugin magic' happens!
